@@ -11,19 +11,21 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  *
  * Copyright 2002-2005 Todd Kulesza
+ * Copyright 2009 Neil Williams  <linux@codehelp.co.uk>
  *
  * Authors:
  * 		Todd Kulesza <todd@dropline.net>
+ * 		Neil Williams  <linux@codehelp.co.uk>
  */
 
 #ifndef _DRIVEL_H_
 #define _DRIVEL_H_
 
 #include "drivel_request.h"
-#include "egg-recent.h"
 #include "utils.h"
 
 #define _XOPEN_SOURCE /* glibc2 needs this */
@@ -31,10 +33,12 @@
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <gconf/gconf-client.h>
-#include <curl/curl.h>
+#include "gtkdateentry.h"
 
+/* blogger and movabletype use this key. */
 #define DRIVEL_APPKEY "EB85AE01035D2303C7D70415B673CE9937BE4056DE691BF2"
 #define DRIVEL_N_RECENT_POSTS 15
+#define GLADE "glade"
 
 typedef struct _DrivelClient DrivelClient;
 typedef struct _DrivelNet DrivelNet;
@@ -113,6 +117,8 @@ struct _DrivelIDs
 	guint spell_language_id;
 	guint last_journal_id;
 	guint technorati_id;
+	guint editor_font_id;
+	guint use_default_font_id;
 	
 	/* loop ids */
 	guint loop_checkfriends_id;
@@ -149,13 +155,17 @@ struct _DrivelGConfData
 	gchar *entry_max;
 	gchar *min_start;
 	gchar *min_post;
+	
+	/* font preferences */
+	gchar *editor_font;
+	gchar *use_default_font;
 };
 
 struct _DrivelJournalEntry
 {
 	gchar *subject;
 	gchar *content;
-	struct tm date_posted;
+	time_t date_posted;
 	gchar *security; /* lj security type */
 	gchar *security_mask; /* lj security mask */
 	gchar *postid; /* post_uri for atom, postid for others */
@@ -163,6 +173,7 @@ struct _DrivelJournalEntry
 	gchar *issued;
 	gchar *link;
 	GPtrArray *properties; /* lj meta data */
+	gchar *tags;
 };
 
 struct _DrivelJournalProp
@@ -175,9 +186,7 @@ struct _DrivelJournalProp
 struct _DrivelNet
 {
 	DrivelBlogAPI api;
-	CURLSH *curl_share;
 	gint fast_servers;
-	GAsyncQueue *msg_queue;
 	GnomeVFSCancellation *cancel;
 };
 
@@ -203,6 +212,8 @@ struct _DrivelClient
 	GtkWidget *login_type;
 	GtkWidget *login_server;
 	GtkWidget *login_remove;
+	GtkWidget *progressbar;
+	GtkStatusbar *statusbar;
 	GtkListStore *login_type_store;
 	
 	/* journal window widgets */
@@ -216,7 +227,7 @@ struct _DrivelClient
 	GtkWidget *journal_comment;
 	GtkWidget *journal_autoformat;
 	GtkWidget *journal_backdate;
-	GtkWidget *journal_date;
+	GtkDateEntry *journal_date;
 	GtkWidget *journal_category;
 	GtkWidget *journal_tags;
 	GtkTextBuffer *buffer;
@@ -241,8 +252,9 @@ struct _DrivelClient
 	GtkAction *menu_view_options;
 	GtkAction *menu_view_misspelled_words;
 	GtkAction *menu_view_html_keywords;
-	EggRecentModel *recent_model;
-	EggRecentViewUIManager *recent_view;
+	GtkRecentData *recent_data;
+	GtkRecentManager *recent_manager;
+	GtkRecentChooser * recent_chooser;
 	DrivelJournalEntry *journal_entry;
 	
 	/* friends dialog */
@@ -296,6 +308,7 @@ struct _DrivelClient
 	/* preferences widgets */
 	GtkWidget *pref_dictionary;
 	GtkWidget *pref_dictionary_box;
+	GtkWidget *pref_font_hbox;
 	
 	GConfClient *client;
 	DrivelGConfData *gconf;
@@ -396,6 +409,6 @@ gint
 sort_journals (DrivelJournal *a, DrivelJournal *b);
 
 void
-clear_recent_entries (GArray *recent);
+clear_recent_entries (GPtrArray *recent);
 
 #endif
