@@ -11,21 +11,23 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  *
  * Copyright 2002-2004 Todd Kulesza
+ * Copyright 2009 Neil Williams  <linux@codehelp.co.uk>
  *
  * Authors:
  * 		Todd Kulesza <todd@dropline.net>
+ * 		Neil Williams  <linux@codehelp.co.uk>
  */
 
 #include <config.h>
 
-#include <gnome.h>
-#include <glade/glade.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 #include <string.h>
-#include <curl/curl.h>
 
 #include "drivel_request.h"
 #include "blog_advogato.h"
@@ -115,7 +117,7 @@ set_active_journal_type (GtkWidget *combo, DrivelBlogAPI api)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean valid;
-	gint type_api;
+	guint type_api;
 	
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 	valid = gtk_tree_model_get_iter_first (model, &iter);
@@ -146,7 +148,7 @@ build_journal_type_combo (GtkListStore **type_store)
 	
 	/* advogato */
 	gtk_list_store_append (*type_store, &iter);
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "advogato.png", NULL);
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "advogato.png", NULL);
 	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	if (pixbuf)
 	{
@@ -160,13 +162,13 @@ build_journal_type_combo (GtkListStore **type_store)
 	gtk_list_store_set (*type_store, &iter,
 			TYPE_ICON, pixbuf_small,
 			TYPE_NAME, "Advogato",
-			TYPE_SERVER, "http://www.advogato.org",
+			TYPE_SERVER, "http://www.advogato.org/XMLRPC",
 			TYPE_API, BLOG_API_ADVOGATO,
 			-1);
 	
 	/* atom */
 	gtk_list_store_append (*type_store, &iter);
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "atom.png", NULL);
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "atom.png", NULL);
 	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	if (pixbuf)
 	{
@@ -186,7 +188,7 @@ build_journal_type_combo (GtkListStore **type_store)
 	
 	/* blogger */
 	gtk_list_store_append (*type_store, &iter);
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "blogger.png", NULL);
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "blogger.png", NULL);
 	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	if (pixbuf)
 	{
@@ -206,7 +208,7 @@ build_journal_type_combo (GtkListStore **type_store)
 	
 	/* livejournal */
 	gtk_list_store_append (*type_store, &iter);
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "livejournal.png", NULL);
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "livejournal.png", NULL);
 	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	if (pixbuf)
 	{
@@ -220,13 +222,13 @@ build_journal_type_combo (GtkListStore **type_store)
 	gtk_list_store_set (*type_store, &iter,
 			TYPE_ICON, pixbuf_small,
 			TYPE_NAME, "LiveJournal",
-			TYPE_SERVER, "http://www.livejournal.com",
+			TYPE_SERVER, "http://www.livejournal.com/interface/xmlrpc",
 			TYPE_API, BLOG_API_LJ,
 			-1);
 	
 	/* movable type */
 	gtk_list_store_append (*type_store, &iter);
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "mt.png", NULL);
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "mt.png", NULL);
 	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 	if (pixbuf)
 	{
@@ -301,7 +303,7 @@ build_journal_user_combo (GtkListStore **store, GSList *list)
 				break;
 			}
 		}
-		path = g_build_filename (DATADIR, "pixmaps", "drivel", icon, NULL);
+		path = g_build_filename (DATADIR, PACKAGE, GLADE, icon, NULL);
 		pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 		if (pixbuf)
 		{
@@ -330,9 +332,9 @@ build_journal_user_combo (GtkListStore **store, GSList *list)
 static void
 load_generic_settings (DrivelClient *dc)
 {
+	debug ("load_generic_settings ()");
 	gtk_editable_delete_text (GTK_EDITABLE (GTK_BIN (dc->login_name)->child), 0, -1);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (dc->login_type), 3); /* 3 is LJ */
-	
 	return;
 }
 
@@ -343,7 +345,8 @@ load_last_user (GtkWidget *combo, GSList *user_list)
 	GtkTreeIter iter;
 	GSList *item;
 	DrivelUser *du;
-	
+
+	debug ("load_last_user ()");
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
 	
 	for (item = user_list; item; item = item->next)
@@ -358,8 +361,8 @@ load_last_user (GtkWidget *combo, GSList *user_list)
 			while (valid)
 			{
 				gchar *username;
-				gint api;
-			
+				guint api;
+
 				gtk_tree_model_get (model, &iter,
 						LOGIN_NAME, &username,
 						LOGIN_API, &api,
@@ -378,7 +381,6 @@ load_last_user (GtkWidget *combo, GSList *user_list)
 			break;
 		}
 	}
-	
 	return;
 }
 
@@ -390,7 +392,7 @@ set_user_login_prefs (DrivelClient *dc)
 	gboolean save_password, autologin;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	
+
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (dc->login_name));
 	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dc->login_name), &iter);
 	gtk_tree_model_get (model, &iter,
@@ -401,6 +403,9 @@ set_user_login_prefs (DrivelClient *dc)
 			LOGIN_SAVE_PASSWORD, &save_password,
 			LOGIN_AUTOLOGIN, &autologin,
 			-1);
+/*	gtk_combo_box_entry_set_text_column 
+		(GTK_COMBO_BOX_ENTRY(dc->login_name), 0);*/
+
 	if (!password)
 		password = g_strdup ("");
 	
@@ -418,7 +423,7 @@ set_user_login_prefs (DrivelClient *dc)
 	return;
 }
 
-static gboolean
+static G_GNUC_UNUSED gboolean
 login_focus_out_cb (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
 	gchar *username;
@@ -427,9 +432,9 @@ login_focus_out_cb (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 	username = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
 
 	if (!validate_username (username))
-	{		
+	{
 		g_free (username);
-			
+		
 		return FALSE;
 	}
 
@@ -457,7 +462,7 @@ clear_password (DrivelClient *dc)
 	return;
 }
 
-static void
+static G_GNUC_UNUSED void
 login_list_changed_cb (GtkWidget *entry, gpointer data)
 {
 	GtkTreeIter iter;
@@ -536,7 +541,7 @@ login_changed_cb (GtkWidget *entry, gpointer data)
 	return;
 }
 
-static void
+static G_GNUC_UNUSED void
 password_changed_cb (GtkWidget *entry, gpointer data)
 {
 	gboolean state, username;
@@ -573,7 +578,7 @@ password_changed_cb (GtkWidget *entry, gpointer data)
 	return;
 }
 
-static gboolean
+static G_GNUC_UNUSED gboolean
 password_focus_out_cb (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
 	gchar *password;
@@ -592,7 +597,7 @@ password_focus_out_cb (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 	return FALSE;
 }
 
-static void
+static G_GNUC_UNUSED void
 type_changed_cb (GtkWidget *box, gpointer data)
 {
 	GtkTreeModel *model;
@@ -600,7 +605,7 @@ type_changed_cb (GtkWidget *box, gpointer data)
 	gchar *server;
 	gint api;
 	DrivelClient *dc = (DrivelClient *) data;
-	
+
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (box));
 	if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (box), &iter))
 	{
@@ -619,14 +624,14 @@ type_changed_cb (GtkWidget *box, gpointer data)
 	return;
 }
 
-static void
+static G_GNUC_UNUSED void
 server_changed_cb (GtkWidget *entry, gpointer data)
 {
 	gboolean state;
 	DrivelClient *dc = (DrivelClient *) data;
 	
 	state = get_sensitivity (entry);
-	
+
 	if (state)
 	{
 		if (get_sensitivity (GTK_BIN (dc->login_name)->child) && 
@@ -645,7 +650,7 @@ server_changed_cb (GtkWidget *entry, gpointer data)
 	return;
 }
 
-static gboolean
+static G_GNUC_UNUSED gboolean
 server_focus_out_cb (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 {
 	gchar *server;
@@ -677,14 +682,14 @@ server_focus_out_cb (GtkWidget *entry, GdkEventFocus *event, gpointer data)
 	return FALSE;
 }
 
-static void
+static G_GNUC_UNUSED void
 save_password_cb (GtkWidget *button, gpointer data)
 {
 	gboolean state;
 	DrivelClient *dc = (DrivelClient *) data;
 	
 	state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-		
+
 	if (state)
 	{
 		gtk_widget_set_sensitive (dc->autologin, TRUE);
@@ -701,68 +706,68 @@ save_password_cb (GtkWidget *button, gpointer data)
 static void
 login (DrivelClient *dc)
 {
-	DrivelRequest *dr;
-	
 	if (last_api != BLOG_API_UNKNOWN)
 	{	
 		dc->user->api = last_api;
 		last_api = BLOG_API_UNKNOWN;
 	}
-	
+	update_status_msg (REQUEST_TYPE_LOGIN);
 	g_mutex_lock (net_mutex);
 	drivel_user_free (dc->user);
 	dc->user = get_drivel_user (dc);
 	g_mutex_unlock (net_mutex);
 	
-	/* build & enqueue the login request */
+	/* build & enqueue the login request 
+	 * 
+	 * Should retrieve the DrivelRequestType
+	 * so that the status bar can be updated.
+	 * 
+	 * */
 	
 	switch (dc->user->api)
 	{
-		case BLOG_API_LJ:
-		{
-			gchar *version;
-			version = g_strdup_printf ("GNOME-Drivel/%s", VERSION);
-			dr = blog_lj_build_login_request (dc->user->username, 
-					dc->user->server, version, dc->moods);
-			g_free (version);
-			debug ("built lj login request");
-			break;
-		}
-		case BLOG_API_MT:
-		{
-			dr = blog_mt_build_login_request (dc->user->server, 
-					dc->user->username, dc->user->password);
-			debug ("built mt login request");
-			break;
-		}
-		case BLOG_API_BLOGGER:
-		{
-			dr = blog_blogger_build_login_request (dc->user->username,
-					dc->user->password, dc->user->server);
-			debug ("built blogger login request");
-			break;
-		}
-		case BLOG_API_ADVOGATO:
-		{
-			dr = blog_advogato_build_login_request (dc->user->username,
-					dc->user->password, dc->user->server);
-			debug ("built advogato login request");
-			break;
-		}
-		case BLOG_API_ATOM:
-		{
-			dr = blog_atom_build_login_request (dc->user->username, 
-					dc->user->password, dc->user->server);
-			debug ("build atom login request");
-			break;
-		}
-		default:
-			dr = NULL;
+	case BLOG_API_LJ:
+	{
+		gchar *version;
+		version = g_strdup_printf ("GNOME-Drivel/%s", VERSION);
+		blog_lj_build_login_request (dc->user->username, 
+					     dc->user->server, version, dc->moods);
+		g_free (version);
+		debug ("built lj login request");
+		break;
 	}
-	
-	net_enqueue_request (dc, dr);
-	
-	return;
+	case BLOG_API_MT:
+	{
+		blog_mt_build_login_request (dc->user->server, 
+					     dc->user->username, dc->user->password);
+		debug ("built mt login request");
+		break;
+	}
+	case BLOG_API_BLOGGER:
+	{
+		blog_blogger_build_login_request (dc->user->username,
+						  dc->user->password, dc->user->server);
+		debug ("built blogger login request");
+		break;
+	}
+	case BLOG_API_ADVOGATO:
+	{
+		blog_advogato_build_login_request (dc->user->username,
+						   dc->user->password, dc->user->server);
+		debug ("built advogato login request");
+		break;
+	}
+	case BLOG_API_ATOM:
+	{
+		blog_atom_build_login_request (dc->user->username, 
+					       dc->user->password, dc->user->server);
+		debug ("build atom login request");
+		break;
+	}
+	default:
+		break;
+	}
+	refresh_recent_chooser (dc);
 }
 
 static void
@@ -781,11 +786,12 @@ work_offline (DrivelClient *dc)
 	last_api = dc->user->api;
 	
 	blog_offline_fake_login (dc);
+	refresh_recent_chooser (dc);
 	
 	return;
 }
 
-static void
+static G_GNUC_UNUSED void
 work_offline_button_cb (GtkWidget *widget, gpointer data)
 {
 	DrivelClient *dc = (DrivelClient *)data;
@@ -802,18 +808,22 @@ remove_username_cb (GtkWidget *menu, gpointer data)
 	GtkTreeIter iter;
 	DrivelUser *to_remove;
 	gchar *username, *server;
-	gint api;
+	gint api, login_name_active;
 	GSList *item;
 	DrivelClient *dc = (DrivelClient *)data;
 	
+	g_return_if_fail (dc);
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (dc->login_name));
+	login_name_active = gtk_combo_box_get_active (GTK_COMBO_BOX (dc->login_name));
+	g_message ("login_name_active = %d", login_name_active);
+	g_return_if_fail (login_name_active > 0);
 	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dc->login_name), &iter);
 	gtk_tree_model_get (model, &iter,
 			LOGIN_NAME, &username,
 			LOGIN_SERVER, &server,
 			LOGIN_API, &api,
 			-1);
-	
+
 	to_remove = drivel_user_new ();
 	to_remove->username = username;
 	to_remove->password = NULL;
@@ -839,16 +849,20 @@ remove_username_cb (GtkWidget *menu, gpointer data)
 static void
 help_cb (GtkWidget *menu, gpointer data)
 {
-	gnome_help_display ("drivel.xml", NULL, NULL);
-	
+	gchar *uri;
+	uri = g_strconcat ("ghelp:", PACKAGE, NULL);
+	g_app_info_launch_default_for_uri (uri, NULL, NULL);
+	g_free (uri);
 	return;
 }
 
 static void
 faq_cb (GtkWidget *menu, gpointer data)
 {
-	gnome_help_display ("drivel.xml", "drivel-faq", NULL);
-	
+	gchar *uri;
+	uri = g_strconcat ("ghelp:", PACKAGE, "?drivel-faq", NULL);
+	g_app_info_launch_default_for_uri (uri, NULL, NULL);
+	g_free (uri);
 	return;
 }
 
@@ -897,9 +911,9 @@ user_list_changed (DrivelClient *dc)
 
 void
 login_window_build (DrivelClient *dc)
-{	
-	GladeXML *xml;
-	GtkWidget *menubar, *offline;
+{
+	GtkBuilder *builder;
+	GtkWidget *menubar, *box, *offline;
 	GtkActionGroup *action_group;
 	GtkUIManager *ui_manager;
 	GtkAccelGroup *accel_group;
@@ -908,16 +922,16 @@ login_window_build (DrivelClient *dc)
 	gchar *path;
 	static GtkActionEntry entries[] =
 	{
-		{ "JournalMenu", NULL, N_("_Journal") },
-		{ "EditMenu", NULL, N_("_Edit") },
-		{ "HelpMenu", NULL, N_("_Help") },
-		{ "Login", "drivel-login", NULL, NULL, NULL, G_CALLBACK (login_button_cb) },
+		{ "JournalMenu", NULL, N_("_Journal"), NULL, NULL, NULL },
+		{ "EditMenu", NULL, N_("_Edit"), NULL, NULL, NULL },
+		{ "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
+		{ "Login", GTK_STOCK_GO_FORWARD, N_("_Log In"), NULL, NULL, G_CALLBACK (login_button_cb) },
 		{ "Remove", GTK_STOCK_REMOVE, N_("Remove Account"), NULL, NULL, G_CALLBACK (remove_username_cb) },
 		{ "Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (exit_cb) },
-		{ "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, "tooltip", G_CALLBACK (edit_preferences_cb) },
+		{ "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, NULL, G_CALLBACK (edit_preferences_cb) },
 		{ "Contents", GTK_STOCK_HELP, N_("_Contents"), "F1", NULL, G_CALLBACK (help_cb) },
 		{ "FAQ", NULL, N_("_Frequently Asked Questions"), NULL, NULL, G_CALLBACK (faq_cb) },
-		{ "About", GNOME_STOCK_ABOUT, N_("_About"), NULL, "tooltip", G_CALLBACK (about_cb) }
+		{ "About", GTK_STOCK_ABOUT, N_("_About"), NULL, NULL, G_CALLBACK (about_cb) }
 	};
 	
 	static const gchar *ui_description =
@@ -943,26 +957,27 @@ login_window_build (DrivelClient *dc)
 		"</ui>"
 	};
 
-	xml = load_glade_xml ("login_window");
-	if (!xml)
+	builder = load_builder_xml (NULL);
+	if (!builder)
 		return;
-	
-	dc->login_window = glade_xml_get_widget (xml, "login_window");
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "drivel-24.png", NULL);
+
+	dc->login_window = GTK_WIDGET(gtk_builder_get_object (builder, "login_window"));
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "drivel-24.png", NULL);
 	gtk_window_set_icon_from_file (GTK_WINDOW (dc->login_window), path, NULL);
 	g_free (path);
 
-	path = g_build_filename (DATADIR, "pixmaps", "drivel", "drivel_splash.png", NULL);
-	gtk_image_set_from_file (GTK_IMAGE (glade_xml_get_widget (xml, "login_window_image")),
-			path);
+	path = g_build_filename (DATADIR, PACKAGE, GLADE, "drivel_splash.png", NULL);
+	gtk_image_set_from_file (GTK_IMAGE (GTK_WIDGET
+			(gtk_builder_get_object (builder, "login_window_image"))), path);
 	g_free (path);
 
 	/* password */
-	dc->login_password = glade_xml_get_widget (xml,
-			"login_window_password");
+	dc->login_password = GTK_WIDGET(gtk_builder_get_object (builder,
+			"login_window_password"));
 	
 	/* journal type */
-	dc->login_type = glade_xml_get_widget (xml, "login_window_type");
+	debug ("setting journal type");
+	dc->login_type = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_type"));
 	dc->login_type_store = gtk_list_store_new (TYPE_COLS,
 			GDK_TYPE_PIXBUF, G_TYPE_STRING,
 			G_TYPE_STRING, G_TYPE_INT);
@@ -989,16 +1004,16 @@ login_window_build (DrivelClient *dc)
 	build_journal_type_combo (&(dc->login_type_store));
 	
 	/* journal server */
-	dc->login_server = glade_xml_get_widget (xml, "login_window_server");
+	dc->login_server = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_server"));
 	
 	/* account options */
-	dc->save_password = glade_xml_get_widget (xml, "login_window_save_password");
-	dc->autologin = glade_xml_get_widget (xml, "login_window_auto_login");
+	dc->save_password = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_save_password"));
+	dc->autologin = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_auto_login"));
 	
 	/* action buttons */
-	dc->login_button = glade_xml_get_widget (xml, "login_window_login");
+	dc->login_button = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_login"));
 	gtk_button_set_use_stock (GTK_BUTTON (dc->login_button), TRUE);
-	offline = glade_xml_get_widget (xml, "login_window_offline");
+	offline = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_offline"));
 	
 	drivel_push_current_window (dc, dc->login_window);
 	
@@ -1018,8 +1033,12 @@ login_window_build (DrivelClient *dc)
 		g_error ("Error while building login window menu");
 	
 	menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
-	gnome_app_set_menus (GNOME_APP (dc->login_window), GTK_MENU_BAR (menubar));
-	
+	box = GTK_WIDGET(gtk_builder_get_object(builder, "dialog-vbox4"));
+	gtk_box_pack_start (GTK_BOX(box), menubar, TRUE, TRUE, 0);
+
+	dc->progressbar = GTK_WIDGET(gtk_builder_get_object(builder, "login_progress_bar"));
+	dc->statusbar = GTK_STATUSBAR(gtk_builder_get_object(builder, "login_statusbar"));
+
 	gtk_widget_show_all (dc->login_window);
 
 	dc->login_menu = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/JournalMenu/Login");
@@ -1032,7 +1051,8 @@ login_window_build (DrivelClient *dc)
 	dc->user_list = g_slist_sort (dc->user_list, user_sort);
 	
 	/* username */
-	dc->login_name = glade_xml_get_widget (xml, "login_window_username");
+	debug ("setting up username");
+	dc->login_name = GTK_WIDGET(gtk_builder_get_object (builder, "login_window_username"));
 	gtk_widget_show (dc->login_name);
 	store = gtk_list_store_new (LOGIN_COLS,
 			G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
@@ -1057,8 +1077,8 @@ login_window_build (DrivelClient *dc)
 			renderer,
 			"text", LOGIN_NAME,
 			NULL);
-	
 	build_journal_user_combo (&store, dc->user_list);
+	debug ("build_journal_user_combo () done");
 	gtk_entry_set_max_length (
 			GTK_ENTRY (GTK_BIN (dc->login_name)->child), 50);
 	gtk_entry_set_width_chars (
@@ -1092,7 +1112,7 @@ login_window_build (DrivelClient *dc)
 			G_CALLBACK (work_offline_button_cb), dc);
 	g_signal_connect (G_OBJECT (dc->login_window), "delete_event",
 			G_CALLBACK (delete_event_cb), dc);
-
+	debug ("signals done");
 	/* first setup the window with sensible defaults... */
 	load_generic_settings (dc);
 	login_changed_cb (GTK_BIN (dc->login_name)->child, dc);
@@ -1105,6 +1125,37 @@ login_window_build (DrivelClient *dc)
 	
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dc->autologin)))
 		login_button_cb (dc->login_button, dc);
-	
 	return;
 }
+
+void refresh_recent_chooser (DrivelClient *dc)
+{
+	GtkRecentFilter *filter;
+
+	dc->recent_manager = gtk_recent_manager_get_default ();
+	if (dc->recent_data)
+		g_free (dc->recent_data);
+	dc->recent_data = g_new0 (GtkRecentData, 1);
+	dc->recent_data->description = _("Drafts");
+	dc->recent_data->mime_type = g_content_type_get_mime_type ("application/x-drivel");
+	dc->recent_data->app_name = PACKAGE;
+	dc->recent_data->is_private = TRUE;
+	dc->recent_data->app_exec = g_strjoin (" ", g_get_prgname (), "%u", NULL);
+	dc->recent_chooser = GTK_RECENT_CHOOSER
+		(gtk_recent_chooser_menu_new_for_manager (dc->recent_manager));
+	gtk_recent_chooser_set_limit(dc->recent_chooser, 4);
+
+	/* This is not working properly yet - 
+	 * available draft files are not showing up but at least the
+	 * use of the filter limits the list to draft drivel posts. */
+	filter = gtk_recent_filter_new ();
+	gtk_recent_filter_set_name (filter, _("Draft drivel posts"));
+	gtk_recent_filter_add_mime_type (filter, "application/x-drivel");
+	gtk_recent_filter_add_application (filter, PACKAGE);
+	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER(dc->recent_chooser), filter);
+	gtk_recent_chooser_set_local_only (GTK_RECENT_CHOOSER(dc->recent_chooser), TRUE);
+	gtk_recent_chooser_set_limit (GTK_RECENT_CHOOSER(dc->recent_chooser), 4);
+	gtk_recent_chooser_set_show_private (GTK_RECENT_CHOOSER(dc->recent_chooser), TRUE);
+	gtk_recent_chooser_set_show_not_found (GTK_RECENT_CHOOSER(dc->recent_chooser), FALSE);
+	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER(dc->recent_chooser), GTK_RECENT_SORT_MRU);
+}
